@@ -14,7 +14,7 @@
 #' @param EP a numeric vector specifying an expected pattern of measurements. Expected patterns(EP.WM, EP.GM and EP.Subcortical) for
 #' WM, GM and Subcortical are included in the package(Note: If you use an expected pattern from the package, the order of regional neuroimaging
 #' traits need to match the corresponding order of the expected pattern). Check patterns(i.e. RVIpkg::EP.WM$SSD, RVIpkg::EP.WM$MDD, RVIpkg::EP.WM$AD
-#'  EP.GM$SSD, RVIpkg::EP.GM$MDD, RVIpkg::EP.GM$AD, EP.Subcortical$SSD, RVIpkg::EP.Subcortical$MDD, RVIpkg::EP.Subcortical$AD.)
+#'  EP.GM$SSD, RVIpkg::EP.GM$MDD, RVIpkg::EP.GM$AD, EP.Subcortical$SSD, RVIpkg::EP.Subcortical$MDD, RVIpkg::EP.Subcortical$AD .etc.)
 #' @param data a data frame contains a column of subject IDs, a column of controls, columns of covariates, columns of responses.
 #' @details
 #' The RVI is developed as a simple measure of agreement between an individual's pattern of regional neuroimaging traits and the expected
@@ -27,8 +27,9 @@
 #' @return A list with the following elements:
 #'   \item{i.norm.resid}{inverse-normal transformed(INT) residuals}
 #'   \item{z.norm.resid}{z-normalized INT residuals}
-#'   \item{RVI.r}{pearson correlation coefficient between the z.norm.resid of subjects and their expected pattern}
-#'   \item{RVI.f}{Fisher transformation of RVI.r}
+#'   \item{RVI}{RVI.r:pearson correlation coefficient between the z.norm.resid of subjects and their expected pattern. Fisher.Z:Fisher
+#'   transformation of RVI.r. Dot.product: dot or scalar product of z.norm.resid and a expected pattern. Z.projection: projection on a pattern.
+#'   cos: cosin between Z.projection and z.norm.resid. magnitude: magnitude of z.norm.resid.}
 #' @note
 #' The RVI_func() function is developed at the Maryland Psychiatric Research Center, Department of Psychiatry,
 #' University of Maryland School of Medicine. This project is supported by NIH R01 EB015611 grant. Please cite our funding if
@@ -89,7 +90,13 @@ RVI_func <- function(ID, DXcontrol, covariates=NULL, resp.range, EP, data) {
 
   RVI.data <- data.frame(ID=data[,which(names(data)==ID)],RVI.r=NA)
   for (i in 1:nrow(z.norm.data)) {RVI.data$RVI.r[i] <- stats::cor(unlist(z.norm.data[i,2:(length(resp.range)+1)]),EP)}
-  RVI.data$RVI.f <- 0.5*log((1+RVI.data$RVI.r)/(1-RVI.data$RVI.r))
+  RVI.data$Fisher.Z <- 0.5*log((1+RVI.data$RVI.r)/(1-RVI.data$RVI.r))
+  for (i in 1:nrow(z.norm.data)) {
+    RVI.data$Dot.product[i] <- sum(unlist(z.norm.data[i,2:(length(resp.range)+1)])*EP)
+    RVI.data$Z.projection[i] <- RVI.data$Dot.product[i]/sqrt(sum(EP^2))
+    RVI.data$cos[i] <- RVI.data$Dot.product[i]/sqrt(sum(unlist(z.norm.data[i,2:(length(resp.range)+1)])^2))/sqrt(sum(EP^2))
+    RVI.data$magnitude[i] <- sqrt(sum(unlist(z.norm.data[i,2:(length(resp.range)+1)])^2))
+    }
 
   out <- list()
   out$i.norm.resid <- i.norm.data
